@@ -14,12 +14,13 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, Mapping, Sequence, Type
+from typing import Any, Dict, Mapping, Sequence, Type, Union
 
 from botocore.client import BaseClient, ClientMeta
 
 from .literals import ConnectionModeType, ConnectorTypeType
 from .type_defs import (
+    CancelFlowExecutionsResponseTypeDef,
     ConnectorProfileConfigTypeDef,
     ConnectorProvisioningConfigTypeDef,
     CreateConnectorProfileResponseTypeDef,
@@ -30,6 +31,7 @@ from .type_defs import (
     DescribeConnectorsResponseTypeDef,
     DescribeFlowExecutionRecordsResponseTypeDef,
     DescribeFlowResponseTypeDef,
+    DestinationFlowConfigOutputTypeDef,
     DestinationFlowConfigTypeDef,
     ListConnectorEntitiesResponseTypeDef,
     ListConnectorsResponseTypeDef,
@@ -37,10 +39,13 @@ from .type_defs import (
     ListTagsForResourceResponseTypeDef,
     MetadataCatalogConfigTypeDef,
     RegisterConnectorResponseTypeDef,
+    SourceFlowConfigOutputTypeDef,
     SourceFlowConfigTypeDef,
     StartFlowResponseTypeDef,
     StopFlowResponseTypeDef,
+    TaskOutputTypeDef,
     TaskTypeDef,
+    TriggerConfigOutputTypeDef,
     TriggerConfigTypeDef,
     UpdateConnectorProfileResponseTypeDef,
     UpdateConnectorRegistrationResponseTypeDef,
@@ -103,6 +108,16 @@ class AppflowClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appflow/client/#can_paginate)
         """
 
+    def cancel_flow_executions(
+        self, *, flowName: str, executionIds: Sequence[str] = ...
+    ) -> CancelFlowExecutionsResponseTypeDef:
+        """
+        Cancels active runs for a flow.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.cancel_flow_executions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appflow/client/#cancel_flow_executions)
+        """
+
     def close(self) -> None:
         """
         Closes underlying endpoint connections.
@@ -119,7 +134,8 @@ class AppflowClient(BaseClient):
         connectionMode: ConnectionModeType,
         connectorProfileConfig: ConnectorProfileConfigTypeDef,
         kmsArn: str = ...,
-        connectorLabel: str = ...
+        connectorLabel: str = ...,
+        clientToken: str = ...
     ) -> CreateConnectorProfileResponseTypeDef:
         """
         Creates a new connector profile associated with your Amazon Web Services
@@ -133,14 +149,17 @@ class AppflowClient(BaseClient):
         self,
         *,
         flowName: str,
-        triggerConfig: TriggerConfigTypeDef,
-        sourceFlowConfig: SourceFlowConfigTypeDef,
-        destinationFlowConfigList: Sequence[DestinationFlowConfigTypeDef],
-        tasks: Sequence[TaskTypeDef],
+        triggerConfig: Union[TriggerConfigTypeDef, TriggerConfigOutputTypeDef],
+        sourceFlowConfig: Union[SourceFlowConfigTypeDef, SourceFlowConfigOutputTypeDef],
+        destinationFlowConfigList: Sequence[
+            Union[DestinationFlowConfigTypeDef, DestinationFlowConfigOutputTypeDef]
+        ],
+        tasks: Sequence[Union[TaskTypeDef, TaskOutputTypeDef]],
         description: str = ...,
         kmsArn: str = ...,
         tags: Mapping[str, str] = ...,
-        metadataCatalogConfig: MetadataCatalogConfigTypeDef = ...
+        metadataCatalogConfig: MetadataCatalogConfigTypeDef = ...,
+        clientToken: str = ...
     ) -> CreateFlowResponseTypeDef:
         """
         Enables your application to create a new flow using Amazon AppFlow.
@@ -309,7 +328,8 @@ class AppflowClient(BaseClient):
         connectorLabel: str = ...,
         description: str = ...,
         connectorProvisioningType: Literal["LAMBDA"] = ...,
-        connectorProvisioningConfig: ConnectorProvisioningConfigTypeDef = ...
+        connectorProvisioningConfig: ConnectorProvisioningConfigTypeDef = ...,
+        clientToken: str = ...
     ) -> RegisterConnectorResponseTypeDef:
         """
         Registers a new custom connector with your Amazon Web Services account.
@@ -318,7 +338,24 @@ class AppflowClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appflow/client/#register_connector)
         """
 
-    def start_flow(self, *, flowName: str) -> StartFlowResponseTypeDef:
+    def reset_connector_metadata_cache(
+        self,
+        *,
+        connectorProfileName: str = ...,
+        connectorType: ConnectorTypeType = ...,
+        connectorEntityName: str = ...,
+        entitiesPath: str = ...,
+        apiVersion: str = ...
+    ) -> Dict[str, Any]:
+        """
+        Resets metadata about your connector entities that Amazon AppFlow stored in its
+        cache.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.reset_connector_metadata_cache)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appflow/client/#reset_connector_metadata_cache)
+        """
+
+    def start_flow(self, *, flowName: str, clientToken: str = ...) -> StartFlowResponseTypeDef:
         """
         Activates an existing flow.
 
@@ -366,7 +403,8 @@ class AppflowClient(BaseClient):
         *,
         connectorProfileName: str,
         connectionMode: ConnectionModeType,
-        connectorProfileConfig: ConnectorProfileConfigTypeDef
+        connectorProfileConfig: ConnectorProfileConfigTypeDef,
+        clientToken: str = ...
     ) -> UpdateConnectorProfileResponseTypeDef:
         """
         Updates a given connector profile associated with your account.
@@ -380,7 +418,8 @@ class AppflowClient(BaseClient):
         *,
         connectorLabel: str,
         description: str = ...,
-        connectorProvisioningConfig: ConnectorProvisioningConfigTypeDef = ...
+        connectorProvisioningConfig: ConnectorProvisioningConfigTypeDef = ...,
+        clientToken: str = ...
     ) -> UpdateConnectorRegistrationResponseTypeDef:
         """
         Updates a custom connector that you've previously registered.
@@ -393,12 +432,15 @@ class AppflowClient(BaseClient):
         self,
         *,
         flowName: str,
-        triggerConfig: TriggerConfigTypeDef,
-        sourceFlowConfig: SourceFlowConfigTypeDef,
-        destinationFlowConfigList: Sequence[DestinationFlowConfigTypeDef],
-        tasks: Sequence[TaskTypeDef],
+        triggerConfig: Union[TriggerConfigTypeDef, TriggerConfigOutputTypeDef],
+        sourceFlowConfig: Union[SourceFlowConfigTypeDef, SourceFlowConfigOutputTypeDef],
+        destinationFlowConfigList: Sequence[
+            Union[DestinationFlowConfigTypeDef, DestinationFlowConfigOutputTypeDef]
+        ],
+        tasks: Sequence[Union[TaskTypeDef, TaskOutputTypeDef]],
         description: str = ...,
-        metadataCatalogConfig: MetadataCatalogConfigTypeDef = ...
+        metadataCatalogConfig: MetadataCatalogConfigTypeDef = ...,
+        clientToken: str = ...
     ) -> UpdateFlowResponseTypeDef:
         """
         Updates an existing flow.
