@@ -28,6 +28,7 @@ __all__ = (
     "ConnectorProvisioningTypeType",
     "ConnectorTypeType",
     "DataPullModeType",
+    "DataTransferApiTypeType",
     "DatadogConnectorOperatorType",
     "DynatraceConnectorOperatorType",
     "ExecutionStatusType",
@@ -56,6 +57,7 @@ __all__ = (
     "ServiceNowConnectorOperatorType",
     "SingularConnectorOperatorType",
     "SlackConnectorOperatorType",
+    "SupportedDataTransferTypeType",
     "TaskTypeType",
     "TrendmicroConnectorOperatorType",
     "TriggerTypeType",
@@ -102,6 +104,7 @@ ConnectorTypeType = Literal[
     "Zendesk",
 ]
 DataPullModeType = Literal["Complete", "Incremental"]
+DataTransferApiTypeType = Literal["ASYNC", "AUTOMATIC", "SYNC"]
 DatadogConnectorOperatorType = Literal[
     "ADDITION",
     "BETWEEN",
@@ -136,7 +139,7 @@ DynatraceConnectorOperatorType = Literal[
     "VALIDATE_NON_ZERO",
     "VALIDATE_NUMERIC",
 ]
-ExecutionStatusType = Literal["Error", "InProgress", "Successful"]
+ExecutionStatusType = Literal["CancelStarted", "Canceled", "Error", "InProgress", "Successful"]
 FileTypeType = Literal["CSV", "JSON", "PARQUET"]
 FlowStatusType = Literal["Active", "Deleted", "Deprecated", "Draft", "Errored", "Suspended"]
 GoogleAnalyticsConnectorOperatorType = Literal["BETWEEN", "PROJECTION"]
@@ -176,7 +179,7 @@ MarketoConnectorOperatorType = Literal[
     "VALIDATE_NUMERIC",
 ]
 OAuth2CustomPropTypeType = Literal["AUTH_URL", "TOKEN_URL"]
-OAuth2GrantTypeType = Literal["AUTHORIZATION_CODE", "CLIENT_CREDENTIALS"]
+OAuth2GrantTypeType = Literal["AUTHORIZATION_CODE", "CLIENT_CREDENTIALS", "JWT_BEARER"]
 OperatorPropertiesKeysType = Literal[
     "CONCAT_FORMAT",
     "DATA_TYPE",
@@ -396,6 +399,7 @@ SlackConnectorOperatorType = Literal[
     "VALIDATE_NON_ZERO",
     "VALIDATE_NUMERIC",
 ]
+SupportedDataTransferTypeType = Literal["FILE", "RECORD"]
 TaskTypeType = Literal[
     "Arithmetic",
     "Filter",
@@ -481,6 +485,7 @@ ServiceName = Literal[
     "apigatewayv2",
     "appconfig",
     "appconfigdata",
+    "appfabric",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -528,6 +533,7 @@ ServiceName = Literal[
     "codecommit",
     "codedeploy",
     "codeguru-reviewer",
+    "codeguru-security",
     "codeguruprofiler",
     "codepipeline",
     "codestar",
@@ -583,6 +589,7 @@ ServiceName = Literal[
     "emr",
     "emr-containers",
     "emr-serverless",
+    "entityresolution",
     "es",
     "events",
     "evidently",
@@ -614,6 +621,7 @@ ServiceName = Literal[
     "importexport",
     "inspector",
     "inspector2",
+    "internetmonitor",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -632,6 +640,7 @@ ServiceName = Literal[
     "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivs-realtime",
     "ivschat",
     "kafka",
     "kafkaconnect",
@@ -667,6 +676,7 @@ ServiceName = Literal[
     "macie",
     "macie2",
     "managedblockchain",
+    "managedblockchain-query",
     "marketplace-catalog",
     "marketplace-entitlement",
     "marketplacecommerceanalytics",
@@ -675,9 +685,11 @@ ServiceName = Literal[
     "medialive",
     "mediapackage",
     "mediapackage-vod",
+    "mediapackagev2",
     "mediastore",
     "mediastore-data",
     "mediatailor",
+    "medical-imaging",
     "memorydb",
     "meteringmarketplace",
     "mgh",
@@ -701,8 +713,11 @@ ServiceName = Literal[
     "opsworks",
     "opsworkscm",
     "organizations",
+    "osis",
     "outposts",
     "panorama",
+    "payment-cryptography",
+    "payment-cryptography-data",
     "personalize",
     "personalize-events",
     "personalize-runtime",
@@ -794,7 +809,9 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "verifiedpermissions",
     "voice-id",
+    "vpc-lattice",
     "waf",
     "waf-regional",
     "wafv2",
